import { Construct } from '@aws-cdk/cdk';
import { BaseNamespaceProps, INamespace, NamespaceBase, NamespaceType } from './namespace';
import { BaseServiceProps, Service } from './service';
export interface HttpNamespaceProps extends BaseNamespaceProps {
}
export interface IHttpNamespace extends INamespace {
    /**
     * The Amazon Resource Name (ARN) of the namespace, such as
     * arn:aws:service-discovery:us-east-1:123456789012:http-namespace/http-namespace-a1bzhi.
     * @attribute
     */
    readonly httpNamespaceArn: string;
    /**
     * The ID of the namespace.
     * @attribute
     */
    readonly httpNamespaceId: string;
}
/**
 * Define an HTTP Namespace
 */
export declare class HttpNamespace extends NamespaceBase implements IHttpNamespace {
    /**
     * A name for the namespace.
     */
    readonly namespaceName: string;
    /**
     * Namespace Id for the namespace.
     */
    readonly namespaceId: string;
    /**
     * Namespace Arn for the namespace.
     */
    readonly namespaceArn: string;
    /**
     * Type of the namespace.
     */
    readonly type: NamespaceType;
    constructor(scope: Construct, id: string, props: HttpNamespaceProps);
    readonly httpNamespaceArn: string;
    readonly httpNamespaceId: string;
    /**
     * Creates a service within the namespace
     */
    createService(id: string, props?: BaseServiceProps): Service;
}
